# Pyessh
A tool for easy to use SSH execute commands at multi-server.


![gif](https://github.com/Leviathan1995/pyessh/blob/master/doc/pyessh.gif)


## Usage

#### Installation

```
# pip3 install paramiko
# pip3 install prompt_toolkit
# pip3 install pyessh
```

#### Editing the Configuration File

```
# vim /etc/local/pyessh.conf
```

add remote server IP addresses at pyessh.conf

```
127.0.0.1
...
```

#### Get Started

```
# pyessh
```
and type your command



## License

MIT
